@@ -5,12 +5,16 @@ from .reflection import create_component, get_class_from_name, istr
 
 from . import logging
 from .logging import logger
+from . import exceptions
+from . import crypto
+from .cache import create_index
 
 from .models import (
     Comparison,
     Criteria,
     Direction,
     Doc,
+    EdgeRequest,
     Span,
     DocToken,
     Edge,
@@ -21,17 +25,22 @@ from .models import (
     FieldCriteria,
     FilterStep,
     Node,
+    NodeKey,
     ParseRequest,
     Registry,
     SearchRequest,
     SearchResponse,
     Step,
+    StoredUser,
     StrTupleField,
     T,
     Token,
     Trail,
     Traversal,
     TripleSep,
+    User,
+    UserStatus,
+    UserToken,
     V,
     Verb,
     WalkStep,
@@ -58,13 +67,13 @@ from .pipeline import (
 )
 from .graph import Graph
 from .searcher import Searcher, DefaultSearcher
+from .user_store import UserStore
 from .kb import KB
 from .cli import cli
 from .rpc import AsyncKB, SyncKB
 from . import contrib
 
 __all__ = (
-    "interfaces",
     "AsyncKB",
     "Comparison",
     "Config",
@@ -73,17 +82,17 @@ __all__ = (
     "DefaultSearcher",
     "Direction",
     "Doc",
-    "GrammarResolver",
-    "Span",
     "DocToken",
     "Edge",
     "EdgeCriteria",
+    "EdgeRequest",
     "Entity",
     "Envelope",
     "ExactNameOnly",
     "F",
     "FieldCriteria",
     "FilterStep",
+    "GrammarResolver",
     "Graph",
     "KB",
     "KeepLongestByKey",
@@ -92,6 +101,7 @@ __all__ = (
     "LatinLowercaseNormalizer",
     "LowerNameOrExactSynonym",
     "Node",
+    "NodeKey",
     "ParseRequest",
     "Pipeline",
     "PipelineConfig",
@@ -100,7 +110,9 @@ __all__ = (
     "SearchRequest",
     "SearchResponse",
     "Searcher",
+    "Span",
     "Step",
+    "StoredUser",
     "StrTupleField",
     "SyncKB",
     "T",
@@ -109,6 +121,10 @@ __all__ = (
     "Trail",
     "Traversal",
     "TripleSep",
+    "User",
+    "UserStatus",
+    "UserStore",
+    "UserToken",
     "V",
     "Verb",
     "WalkStep",
@@ -119,9 +135,13 @@ __all__ = (
     "cli",
     "contrib",
     "create_component",
+    "create_index",
+    "crypto",
     "ensure_iterable",
     "environ",
+    "exceptions",
     "get_class_from_name",
+    "interfaces",
     "is_iterable",
     "istr",
     "label_filter",
