@@ -3,5 +3,6 @@ from . import readers
 from . import writers
 from . import services
 from . import commands
+from . import users
 
-__all__ = ("cli", "readers", "writers", "services", "commands")
+__all__ = ("cli", "readers", "writers", "services", "commands", "users")
