@@ -9,6 +9,7 @@ from .env import environ
 from .logging import logger
 from .models.registry import Registry
 from .reflection import create_component
+from .crypto import generate_secret
 
 
 class PipelineConfig(BaseModel):
@@ -56,8 +57,9 @@ class Config(BaseModel):
     modules: List[str] = Field(default_factory=list)
     normalizer: str = "entitykb.LatinLowercaseNormalizer"
     searcher: str = "entitykb.DefaultSearcher"
-    terms: str = "entitykb.TermsIndex"
     tokenizer: str = "entitykb.WhitespaceTokenizer"
+    user_store: str = "entitykb.UserStore"
+    secret_key: str = Field(default_factory=generate_secret)
 
     pipelines: Dict[str, PipelineConfig] = Field(
         default_factory=PipelineConfig.default_factory
@@ -78,7 +80,7 @@ class Config(BaseModel):
         return Path(self.file_path).parent
 
     @classmethod
-    def create(cls, root=None) -> "Config":
+    def create(cls, root=None, config=None) -> "Config":
         config_file_path = cls.get_file_path(root=root)
 
         data = {}
@@ -86,7 +88,7 @@ class Config(BaseModel):
             with config_file_path.open("r") as fp:
                 data = json.load(fp)
 
-        config = cls(file_path=config_file_path, **data)
+        config = config or cls(file_path=config_file_path, **data)
 
         if not config_file_path.is_file():
             config_file_path.parent.mkdir(parents=True, exist_ok=True)
@@ -112,9 +114,20 @@ class Config(BaseModel):
 
     def info(self) -> dict:
         info = self.dict()
-        info["root"] = self.root
+        info["secret_key"] = self.secret_key[:6] + "..."
+        info["root"] = str(self.root)
         return info
 
+    def create_user_store(self):
+        from entitykb.user_store import UserStore
+
+        return create_component(
+            value=self.user_store,
+            default_cls=UserStore,
+            root=self.root,
+            secret_key=self.secret_key,
+        )
+
     def create_normalizer(self):
         from entitykb.pipeline.normalizers import LatinLowercaseNormalizer
 
