@@ -1,5 +1,6 @@
+from .users import User, StoredUser, UserToken
 from .doc import Token, DocToken, Doc, Span, ParseRequest
-from .enums import Direction, Comparison, TripleSep
+from .enums import Direction, Comparison, TripleSep, UserStatus
 from .fields import StrTupleField
 from .funcs import (
     camel_to_snake,
@@ -8,7 +9,7 @@ from .funcs import (
     under_limit,
     label_filter,
 )
-from .node import Node, Edge
+from .node import Node, Edge, NodeKey, IEdge
 from .entity import Entity
 from .traverse import (
     F,
@@ -24,10 +25,12 @@ from .traverse import (
     WalkStep,
 )
 from .registry import Registry
-from .search import SearchRequest, Hop, Trail, SearchResponse
+from .search import SearchRequest, Hop, Trail, SearchResponse, EdgeRequest
 from .serialization import Envelope
 
 __all__ = (
+    "AccessToken",
+    "AccessTokenData",
     "Comparison",
     "Criteria",
     "Direction",
@@ -36,24 +39,31 @@ __all__ = (
     "DocToken",
     "Edge",
     "EdgeCriteria",
+    "EdgeRequest",
     "Entity",
     "Envelope",
     "F",
     "FieldCriteria",
     "FilterStep",
     "Hop",
+    "IEdge",
     "Node",
+    "NodeKey",
     "ParseRequest",
     "Registry",
     "SearchRequest",
     "SearchResponse",
     "Step",
+    "StoredUser",
     "StrTupleField",
     "T",
     "Token",
     "Trail",
     "Traversal",
     "TripleSep",
+    "User",
+    "UserStatus",
+    "UserToken",
     "V",
     "Verb",
     "WalkStep",
